@@ -3,6 +3,7 @@
 require 'spec_helper'
 
 require 'puppet/indirector/catalog/puppetdb'
+require 'puppet/util/puppetdb'
 require 'puppet/util/puppetdb/command_names'
 require 'json'
 
@@ -10,6 +11,7 @@ describe Puppet::Resource::Catalog::Puppetdb do
   before :each do
     Puppet::Util::Puppetdb.stubs(:server).returns 'localhost'
     Puppet::Util::Puppetdb.stubs(:port).returns 0
+    create_environmentdir("my_environment")
   end
 
   describe "#save" do
@@ -71,7 +73,7 @@ describe Puppet::Resource::Catalog::Puppetdb do
     # create the catalog based on that manifest simply by asking for it.
     def catalog_data_hash
       Puppet[:code] = resource.to_manifest
-      catalog.to_pson_data_hash['data']
+      catalog.to_data_hash
     end
 
     describe "#add_transaction_uuid" do
@@ -111,18 +113,20 @@ describe Puppet::Resource::Catalog::Puppetdb do
     end
 
     describe "#stringify_titles" do
-      it "should make all resource titles strings if they aren't" do
-        Puppet[:code] = <<-MANIFEST
+      if Puppet::Util::Puppetdb.puppet3compat?
+        it "should make all resource titles strings if they aren't" do
+          Puppet[:code] = <<-MANIFEST
           $foo = true
           notify { $foo: }
         MANIFEST
 
-        hash = catalog.to_pson_data_hash['data']
-        result = subject.stringify_titles(hash)
+          hash = catalog.to_data_hash
+          result = subject.stringify_titles(hash)
 
-        result['resources'].should be_any { |res|
-          res['type'] == 'Notify' and res['title'] == 'true'
-        }
+          result['resources'].should be_any { |res|
+            res['type'] == 'Notify' and res['title'] == 'true'
+          }
+        end
       end
     end
 
@@ -166,7 +170,7 @@ describe Puppet::Resource::Catalog::Puppetdb do
             #  way to accomplish this...
             Puppet[:code] = file_resource.to_manifest
 
-            hash = subject.add_parameters_if_missing(catalog.to_pson_data_hash['data'])
+            hash = subject.add_parameters_if_missing(catalog.to_data_hash)
             result = subject.add_namevar_aliases(hash, catalog)
 
             resource = result['resources'].find do |res|
@@ -314,7 +318,7 @@ describe Puppet::Resource::Catalog::Puppetdb do
         other_resource = Puppet::Resource.new(:notify, 'noone', :parameters => {:require => "Notify[anyone]"})
         Puppet[:code] = [resource, other_resource].map(&:to_manifest).join
 
-        hash = catalog.to_pson_data_hash['data']
+        hash = catalog.to_data_hash
         subject.add_parameters_if_missing(hash)
         result = subject.synthesize_edges(hash, catalog)
 
@@ -330,7 +334,7 @@ describe Puppet::Resource::Catalog::Puppetdb do
         Puppet[:code] = [resource, other_resource].map(&:to_manifest).join
         Puppet[:code] << "Notify[anyone] -> Notify[noone]"
 
-        hash = catalog.to_pson_data_hash['data']
+        hash = catalog.to_data_hash
         subject.add_parameters_if_missing(hash)
         result = subject.synthesize_edges(hash, catalog)
 
@@ -442,6 +446,30 @@ describe Puppet::Resource::Catalog::Puppetdb do
           result['edges'].should include(edge)
         end
 
+        if Puppet::Util::Puppetdb.puppet3compat?
+          it "should add edges which refer to collected virtual resources with hyphens in the classname" do
+            Puppet[:code] = <<-MANIFEST
+          define foo-bar- (){}
+          @foo-bar- { 'baz': }
+
+          notify { source:
+            before => Foo-bar-[baz],
+          }
+
+          Foo-bar- <| |>
+            MANIFEST
+
+            result = subject.munge_catalog(catalog)
+            other_edge = {
+              'source' => {'type' => 'Notify', 'title' => 'source'},
+              'target' => {'type' => 'Foo-bar-', 'title' => 'baz'},
+              'relationship' => 'before'
+            }
+
+            result['edges'].should include(other_edge)
+          end
+        end
+
         it "should add edges defined on collected virtual resources" do
           Puppet[:code] = <<-MANIFEST
           @notify { source:
@@ -524,7 +552,7 @@ describe Puppet::Resource::Catalog::Puppetdb do
         resource[:require] = 'Notify[another_thing]'
         Puppet[:code] = [resource, other_resource].map(&:to_manifest).join
 
-        hash = catalog.to_pson_data_hash['data']
+        hash = catalog.to_data_hash
         subject.add_parameters_if_missing(hash)
         subject.add_namevar_aliases(hash, catalog)
         result = subject.synthesize_edges(hash, catalog)
